import javascript
from browser import document

select = document.select
re = javascript.RegExp.new
jstring = javascript.String.new

X_TO_D_REGEXES = [
    (re('C[xX]', 'g'), 'Ĉ'),
    (re('c[xX]', 'g'), 'ĉ'),
    (re('G[xX]', 'g'), 'Ĝ'),
    (re('g[xX]', 'g'), 'ĝ'),
    (re('H[xX]', 'g'), 'Ĥ'),
    (re('h[xX]', 'g'), 'ĥ'),
    (re('J[xX]', 'g'), 'Ĵ'),
    (re('j[xX]', 'g'), 'ĵ'),
    (re('S[xX]', 'g'), 'Ŝ'),
    (re('s[xX]', 'g'), 'ŝ'),
    (re('U[xX]', 'g'), 'Ŭ'),
    (re('u[xX]', 'g'), 'ŭ'),
]
D_TO_X_REGEXES = [
    (re('Ĉ', 'g'), 'Cx'),
    (re('ĉ', 'g'), 'cx'),
    (re('Ĝ', 'g'), 'Gx'),
    (re('ĝ', 'g'), 'gx'),
    (re('Ĥ', 'g'), 'Hx'),
    (re('ĥ', 'g'), 'hx'),
    (re('Ĵ', 'g'), 'Jx'),
    (re('ĵ', 'g'), 'jx'),
    (re('Ŝ', 'g'), 'Sx'),
    (re('ŝ', 'g'), 'sx'),
    (re('Ŭ', 'g'), 'Ux'),
    (re('ŭ', 'g'), 'ux'),
]

ALL_CAPS_ELEMENT = document['all-caps']
INPUT_ELEMENT = document['input']
OUTPUT_ELEMENT = document['output']


def x_to_diacritics(text):
    s = jstring(text)
    res = ''
    for regex, replacement in X_TO_D_REGEXES:
        res = s.replace(regex, replacement)
        s = jstring(res)
    return res


def diacritics_to_x(text, all_caps):
    s = jstring(text)
    res = ''
    for regex, replacement in D_TO_X_REGEXES:
        repl = replacement.upper() if all_caps and replacement[0].isupper() else replacement
        res = s.replace(regex, repl)
        s = jstring(res)
    return res


def convert(_):
    text = INPUT_ELEMENT.value
    input_mode = select('input[type="radio"][name="input"]:checked')[0].value
    output_mode = select('input[type="radio"][name="output"]:checked')[0].value
    all_caps = ALL_CAPS_ELEMENT.checked

    if input_mode == 'x-notation' and output_mode == 'diacritics':
        text = x_to_diacritics(text)
    elif input_mode == 'diacritics' and output_mode == 'x-notation':
        text = diacritics_to_x(text, all_caps)

    OUTPUT_ELEMENT.text = text


def toggle(event):
    ALL_CAPS_ELEMENT.disabled = \
        not select('input[type="radio"][name="output"][value="x-notation"]')[0].checked
    convert(event)


INPUT_ELEMENT.bind('keyup', convert)
for e in select('input[type="radio"][name="input"]'):
    e.bind('change', convert)
for e in select('input[type="radio"][name="output"]'):
    e.bind('change', toggle)
ALL_CAPS_ELEMENT.bind('change', convert)

select('input[type="radio"][name="input"][value="x-notation"]')[0].checked = True
select('input[type="radio"][name="output"][value="diacritics"]')[0].checked = True
